==> rogo-7.3.0.tar.gz: qti/tmpl/import_locked.php <==
<?php

// This file is part of Rogō
//
// Rogō is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Rogō is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Rogō.  If not, see <http://www.gnu.org/licenses/>.

/**
 *
 * @author Adam Clarke
 * @version 1.0
 * @copyright Copyright (c) 2011 The University of Nottingham
 * @package
 */

require_once '../include/staff_auth.inc';
?>
<!DOCTYPE html>
<html onscroll="scrollXY();" onclick="hideMenus();">
<head>
  <meta http-equiv="X-UA-Compatible" content="IE=edge" />
  <meta http-equiv="content-type" content="text/html;charset=<?php echo $configObject->get('cfg_page_charset') ?>" />

    <title>Rog&#333;: <?php echo $string['importfromqti'] ?></title>

    <link rel="stylesheet" type="text/css" href="../css/body.css" />
    <link rel="stylesheet" type="text/css" href="../css/header.css" />
    <link rel="stylesheet" type="text/css" href="../css/dialog.css" />
    <link rel="stylesheet" type="text/css" href="../css/submenu.css" />
    <style type="text/css">
        span.killer {float:none}
    </style>

    <script id="rogoconfig" data-root="<?php echo $configObject->get('cfg_root_path'); ?>"></script>
    <script src='../js/require.js'></script>
    <script src='../js/main.min.js'></script>
    <script type="text/javascript" src="../js/importinit.min.js"></script>
</head>

<?php
require '../include/paper_options.php';

require '../include/toprightmenu.inc';

echo draw_toprightmenu(224);
?>
<div id="content">
  <?php
    echo "<div class=\"head_title\">\n";
    echo "<div><img src=\"../artwork/toprightmenu.gif\" id=\"toprightmenu_icon\" /></div>\n";
    echo '<div class="breadcrumb">';
    $modutils = module_utils::get_instance();
    echo '<a href="../index.php">' . $string['home'] . '</a>';
    if (isset($_GET['module']) and $_GET['module'] != '') {
        echo '<img src="../artwork/breadcrumb_arrow.png" class="breadcrumb_arrow" alt="-" /><a href="../module/index.php?module=' . $_GET['module'] . '">' . $modutils->get_moduleid_from_id($_GET['module'], $mysqli) . '</a>';
    } elseif ($folder != '') {
        echo '<img src="../artwork/breadcrumb_arrow.png" class="breadcrumb_arrow" alt="-" /><a href="../folder/index.php?folder=' . $folder . '">' . $folder_name . '</a>';
    }
    echo '<img src="../artwork/breadcrumb_arrow.png" class="breadcrumb_arrow" alt="-" /><a href="../paper/details.php?paperID=' . $paperID . '">' . $paper_title . '</a>';

    echo '</div><div class="page_title">' . $string['importfromqti'] . '</div>';
    echo '</div>';
    ?>
    <br/>
    <br/>
    <br/>
    <br/>

    <table cellspacing="0" cellpadding="0" border="0" style="width:500px; text-align:left" class="dialog_border">
        <tr>
            <td class="inline_dialog_header" style="width:55px"><img src="../artwork/ims_logo.png" width="47" height="44" alt="IMS Logo" /></td><td class="dialog_header" style="width:445px"><?php echo $string['import'] ?></td>
        </tr>
        <tr>
            <td class="dialog_body" colspan="2">

                <div style="padding-top:16px;padding-left:16px;padding-right:16px;">
                    <table border="0" cellpadding="0" cellspacing="0" style="width:100%">
                        <tr><td colspan="2" style="height:32px; text-align:right"><img src="../artwork/paper_locked_padlock.png" width="19" height="24" alt="Locked" />&nbsp;&nbsp;</td><td colspan="7" style="height:32px; vertical-align:middle;"><strong><?php echo $string['paperlocked'] ?></strong>&nbsp;&nbsp;&nbsp;<?php echo $string['paperlockedmsg'] ?><a href="#" class="blacklink" onclick="return false;"><?php echo $string['lockedlink'] ?></a></td></tr>
                    </table>
                    <br/>
                </div>
            </td>
        </tr>
    </table>

</div>
</body>
</html>

==> rogo-7.4.2.tar.gz: qti/tmpl/import_locked.php <==
<?php

// This file is part of Rogō
//
// Rogō is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Rogō is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Rogō.  If not, see <http://www.gnu.org/licenses/>.

/**
 *
 * @author Adam Clarke
 * @version 1.0
 * @copyright Copyright (c) 2011 The University of Nottingham
 * @package
 */

require_once '../include/staff_auth.inc';
?>
<!DOCTYPE html>
<html onscroll="scrollXY();" onclick="hideMenus();">
<head>
  <meta http-equiv="X-UA-Compatible" content="IE=edge" />
  <meta http-equiv="content-type" content="text/html;charset=<?php echo $configObject->get('cfg_page_charset') ?>" />

    <title>Rog&#333;: <?php echo $string['importfromqti'] ?></title>

    <link rel="stylesheet" type="text/css" href="../css/body.css" />
    <link rel="stylesheet" type="text/css" href="../css/header.css" />
    <link rel="stylesheet" type="text/css" href="../css/dialog.css" />
    <link rel="stylesheet" type="text/css" href="../css/submenu.css" />
    <style type="text/css">
        span.killer {float:none}
    </style>

    <script id="rogoconfig" data-lang="<?php echo \LangUtils::getLang($cfg_web_root); ?>" data-root="<?php echo $configObject->get('cfg_root_path'); ?>"></script>
    <script src='../js/require.js'></script>
    <script src='../js/main.min.js'></script>
    <script type="text/javascript" src="../js/importinit.min.js"></script>
</head>

<?php
require '../include/paper_options.php';

require '../include/toprightmenu.inc';

echo draw_toprightmenu(224);
?>
<div id="content">
  <?php
    echo "<div class=\"head_title\">\n";
    echo "<div><img src=\"../artwork/toprightmenu.gif\" id=\"toprightmenu_icon\" /></div>\n";
    echo '<div class="breadcrumb">';
    $modutils = module_utils::get_instance();
    echo '<a href="../index.php">' . $string['home'] . '</a>';
    if (isset($_GET['module']) and $_GET['module'] != '') {
        echo '<img src="../artwork/breadcrumb_arrow.png" class="breadcrumb_arrow" alt="-" /><a href="../module/index.php?module=' . $_GET['module'] . '">' . $modutils->get_moduleid_from_id($_GET['module'], $mysqli) . '</a>';
    } elseif ($folder != '') {
        echo '<img src="../artwork/breadcrumb_arrow.png" class="breadcrumb_arrow" alt="-" /><a href="../folder/index.php?folder=' . $folder . '">' . $folder_name . '</a>';
    }
    echo '<img src="../artwork/breadcrumb_arrow.png" class="breadcrumb_arrow" alt="-" /><a href="../paper/details.php?paperID=' . $paperID . '">' . $paper_title . '</a>';

    echo '</div><div class="page_title">' . $string['importfromqti'] . '</div>';
    echo '</div>';
    ?>
    <br/>
    <br/>
    <br/>
    <br/>

    <table cellspacing="0" cellpadding="0" border="0" style="width:500px; text-align:left" class="dialog_border">
        <tr>
            <td class="inline_dialog_header" style="width:55px"><img src="../artwork/ims_logo.png" width="47" height="44" alt="IMS Logo" /></td><td class="dialog_header" style="width:445px"><?php echo $string['import'] ?></td>
        </tr>
        <tr>
            <td class="dialog_body" colspan="2">

                <div style="padding-top:16px;padding-left:16px;padding-right:16px;">
                    <table border="0" cellpadding="0" cellspacing="0" style="width:100%">
                        <tr><td colspan="2" style="height:32px; text-align:right"><img src="../artwork/paper_locked_padlock.png" width="19" height="24" alt="Locked" />&nbsp;&nbsp;</td><td colspan="7" style="height:32px; vertical-align:middle;"><strong><?php echo $string['paperlocked'] ?></strong>&nbsp;&nbsp;&nbsp;<?php echo $string['paperlockedmsg'] ?><a href="#" class="blacklink" onclick="return false;"><?php echo $string['lockedlink'] ?></a></td></tr>
                    </table>
                    <br/>
                </div>
            </td>
        </tr>
    </table>

</div>
</body>
</html>
